@@ -38,16 +38,15 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=powerpc-unknown-linux-musl' "
                 "'--host=powerpc-unknown-linux-musl' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.11.8_p1' "
-                "'--htmldir=/usr/share/doc/python-3.11.8_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.11.9' "
+                "'--htmldir=/usr/share/doc/python-3.11.9/html' "
                 "'--libdir=/usr/lib' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -66,9 +65,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -142,7 +141,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -613,15 +612,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.smarfrv5/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.jputrqrg/bin/ebuild-helpers/xattr/install '
             '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.smarfrv5/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.jputrqrg/bin/ebuild-helpers/xattr/install '
                  '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.smarfrv5/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.jputrqrg/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.smarfrv5/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.jputrqrg/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.smarfrv5/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.jputrqrg/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -965,12 +964,12 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
@@ -994,7 +993,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'powerpc-unknown-linux-musl-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1038,10 +1037,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1072,8 +1071,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.8_p1/work/Python-3.11.8',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
